Package: nethet
Type: Package
Title: A bioconductor package for high-dimensional exploration of
        biological network heterogeneity
Version: 1.45.0
Date: 2020-09-27
Author: Nicolas Staedler, Frank Dondelinger
Maintainer: Nicolas Staedler <staedler.n@gmail.com>,
 Frank Dondelinger <fdondelinger.work@gmail.com>
Description: Package nethet is an implementation of statistical solid
    methodology enabling the analysis of network heterogeneity from
    high-dimensional data. It combines several implementations of recent
    statistical innovations useful for estimation and comparison of networks in
    a heterogeneous, high-dimensional setting. In particular, we provide code
    for formal two-sample testing in Gaussian graphical models (differential
    network and GGM-GSA; Stadler and Mukherjee, 2013, 2014) and make a novel
    network-based clustering algorithm available (mixed graphical lasso,
    Stadler and Mukherjee, 2013).
Imports: glasso, mvtnorm, GeneNet, huge, CompQuadForm, ggm, mclust,
        parallel, GSA, limma, multtest, ICSNP, glmnet, network,
        ggplot2, grDevices, graphics, stats, utils
Suggests: knitr, xtable, BiocStyle, testthat
biocViews: Clustering, GraphAndNetwork
VignetteBuilder: knitr
License: GPL-2
Packaged: 2026-04-29 00:05:54 UTC; biocbuild
RoxygenNote: 6.1.1
git_url: https://git.bioconductor.org/packages/nethet
git_branch: devel
git_last_commit: b4bb182
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
