% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diffnet.R
\name{lambda.max}
\alias{lambda.max}
\title{Lambdamax}
\usage{
lambda.max(x)
}
\arguments{
\item{x}{no descr}
}
\value{
no descr
}
\description{
Lambdamax
}
\author{
n.stadler
}
\keyword{internal}
