% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mixglasso.R
\name{glasso.parcor}
\alias{glasso.parcor}
\title{Graphical Lasso based on partial correlation penalty}
\usage{
glasso.parcor(s, rho, penalize.diagonal, maxiter = 1000, term = 10^{   
   -3 }, verbose = FALSE)
}
\arguments{
\item{s}{no descr}

\item{rho}{no descr}

\item{penalize.diagonal}{no descr}

\item{maxiter}{no descr}

\item{term}{no descr}

\item{verbose}{set to TRUE to print out progress.}
}
\value{
w; wi; iter
}
\description{
Graphical Lasso based on partial correlation penalty
}
\author{
n.stadler
}
\keyword{internal}
