% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diffregr.R
\name{ww.mat.diffregr}
\alias{ww.mat.diffregr}
\title{Computation M matrix and eigenvalues}
\usage{
ww.mat.diffregr(Sig, act, act1, act2)
}
\arguments{
\item{Sig}{no descr}

\item{act}{no descr}

\item{act1}{no descr}

\item{act2}{no descr}
}
\value{
no descr
}
\description{
Computation M matrix and eigenvalues
}
\author{
n.stadler
}
\keyword{internal}
