% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auxfunc.R
\name{summary.ggmgsa}
\alias{summary.ggmgsa}
\title{Summary function for object of class 'ggmgsa'}
\usage{
\method{summary}{ggmgsa}(object, ...)
}
\arguments{
\item{object}{object of class 'ggmgsa'}

\item{...}{Other arguments}
}
\value{
aggregated p-values
}
\description{
Summary function for object of class 'ggmgsa'
}
\author{
nicolas
}
