% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auxfunc.R
\name{print.nethetsummary}
\alias{print.nethetsummary}
\title{Print function for object of class 'nethetsummmary'}
\usage{
\method{print}{nethetsummary}(x, ...)
}
\arguments{
\item{x}{object of class 'nethetsummary'}

\item{...}{Other arguments}
}
\value{
Function does not return anything.
}
\description{
Print function for object of class 'nethetsummary'
}
\author{
frankd
}
