% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mixglasso.R
\name{EXPStep.mix}
\alias{EXPStep.mix}
\title{Performs EStep}
\usage{
EXPStep.mix(logphi, mix.prob)
}
\arguments{
\item{logphi}{no descr}

\item{mix.prob}{no descr}
}
\value{
list consiting of
\item{u}{responsibilities}
\item{LL}{loglikelihood}
}
\description{
Performs EStep
}
\author{
n.stadler
}
\keyword{internal}
