% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mixglasso.R
\name{glasso.invcor}
\alias{glasso.invcor}
\title{Graphical Lasso based on inverse covariance penalty}
\usage{
glasso.invcor(s, rho, penalize.diagonal, term = 10^{     -3 })
}
\arguments{
\item{s}{no descr}

\item{rho}{no descr}

\item{penalize.diagonal}{no descr}

\item{term}{no descr}
}
\value{
w; wi; iter
}
\description{
Graphical Lasso based on inverse covariance penalty
}
\author{
n.stadler
}
\keyword{internal}
