% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ggmgsa.R
\name{my.ttest2}
\alias{my.ttest2}
\title{T-test}
\usage{
my.ttest2(x1, x2)
}
\arguments{
\item{x1}{no descr}

\item{x2}{no descr}
}
\value{
no descr
}
\description{
T-test (unequal variances)
}
\author{
n.stadler
}
\keyword{internal}
